##  Workspace Notifications
The Workspace Notifications tab allows you to see different domains & topics that you can subscribe to on a certain workspace. Any change done on this screen will only affect the workspace you are currently in.
The administrator can configure for each topic, which options the users of the workspace can choose from for the <Frequency> of the notification (Never, Instant, Daily, Weekly) and which of these options should be the <Default> for new users that did not choose one explicitly.
![](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio274e566b7a441014b262fa0831f3e5b2_LowRes.png)
By disabling all options but <Never>, the administrator can completely disable a topic. Similarly, they can enforce notifications for specific topics by only choosing the option <Instant>.
### Fact Sheet Update Details
Under the Fact Sheets topic, you will be able to opt-in for showing details in Fact Sheet update notifications. Once this is enabled, the users of your workspace that have subscribed to Fact Sheet updated notifications on Email will see which field has changed on the Fact Sheet and the content of what has changed.
![](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio27519f357a44101485e0f31a776544ce_LowRes.png)
